@@ -52,6 +52,7 @@ class _ShelfBoundDeclarativeMeta(flask_sqlalchemy._BoundDeclarativeMeta):
                 name = cls.pagename
             else:
                 name = flask_sqlalchemy._camelcase_re.sub(_join, name).lstrip('_').replace('_page', '').replace('_', '-')
+            
             __mapper_args__ = {
                 'polymorphic_identity': name
             }
@@ -169,11 +170,9 @@ class ShelfAlchemy(flask_sqlalchemy.SQLAlchemy):
         super(ShelfAlchemy, self).create_all()
 
         for cls in self.pages:
-            name = cls.__mapper_args__['polymorphic_identity']
-            if cls.query.filter_by(name=name).count() == 0:
-                page = cls(name=name)
-                db.session.add(page)
-                db.session.commit()
+            if self.session.query(cls).count() == 0:
+                self.session.add(cls())
+        self.session.commit()
 
         
 
